<?php


class shamra_exchange_widget extends WP_Widget {

    function __construct() {
        parent::__construct(
            'shamra_exchange_widget',
            __('Shamra Exchange Widget', 'shamra_exchange_widget_domain'),
            array(
                'classname' => 'shamra_exchange_widget_container',
                'description' => __( 'A Widget for displaying exchange rates according to shamra.sy', 'shamra_exchange_widget_domain' ),
                )
        );
    }

    public function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', $instance['title'] );
        $token = isset( $instance[ 'token' ])? esc_attr($instance[ 'token' ]):'';
        $source = isset( $instance[ 'source' ])? esc_attr($instance[ 'source' ]):'both';
        $currencies = isset( $instance[ 'currencies' ])? esc_attr($instance[ 'currencies' ]):'all';
        echo $args['before_widget'];
        if ( ! empty( $title ) )
            echo $args['before_title'] . $title . $args['after_title'];
        $dataToken = 'data-token="' . $token . '"';
        $dataTarget = 'data-target="shamra-exchange-widget"';
        $dataSource = 'data-source="' . $source . '"';
        $dataCurrencies = 'data-currencies="' . $currencies . '"';
        $pluginScriptUrl =  plugins_url( '/assets/js/exchange-api.js',__FILE__ );
        $src = 'src="' . $pluginScriptUrl . '"';
        echo "<script {$src} {$dataToken} {$dataTarget} {$dataSource} {$dataCurrencies}></script>";
        echo "<div id='shamra-exchange-widget'>جاري تحميل أسعار صرف العملات من شمرا...</div>";
        echo $args['after_widget'];
    }

// Widget Backend
    public function form( $instance ) {
        $title = isset( $instance[ 'title' ])? esc_attr($instance[ 'title' ]):__( 'New title', 'shamra_exchange_widget_domain' );
        $token = isset( $instance[ 'token' ])? esc_attr($instance[ 'token' ]):'';
        $source = isset( $instance[ 'source' ])? esc_attr($instance[ 'source' ]):'both';
        $currencies = isset( $instance[ 'currencies' ])? esc_attr($instance[ 'currencies' ]):'all';
        $sourceChecked = [
            'both' => false,
            'pm' => false,
            'cbn' => false
        ];
        $sourceChecked[$source] = true;
        ?>
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'token' ); ?>"><?php _e( 'Token:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'token' ); ?>" name="<?php echo $this->get_field_name( 'token' ); ?>" type="text" value="<?php echo esc_attr( $token ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'source' ); ?>"><?php _e( 'Source:' ); ?></label>
            <select class="widefat" id="<?php echo $this->get_field_id( 'source' ); ?>" name="<?php echo $this->get_field_name( 'source' ); ?>">
                <option value="both" <?php echo ($sourceChecked['both'])?'selected':''; ?>><?php _e('Both (Central bank and market)'); ?></option>
                <option value="pm" <?php echo ($sourceChecked['pm'])?'selected':''; ?>><?php _e('Central Bank'); ?></option>
                <option value="cbn" <?php echo ($sourceChecked['cbn'])?'selected':''; ?>><?php _e('Market'); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'currencies' ); ?>"><?php _e( 'Currencies:' ); ?></label>
	    <br/>
	    Write "all" to display all currencies, or abbreviations of the currencies you want seperated by commas like "usd,eur"
            <input class="widefat" id="<?php echo $this->get_field_id( 'currencies' ); ?>" name="<?php echo $this->get_field_name( 'currencies' ); ?>" type="text" value="<?php echo esc_attr( $currencies ); ?>" />
        </p>
	<p>
	You can check documentation at <a href="https://shamra.sy/developer/services/العملات">Shamra</a> official website.
	</p>
	<p style="color: gray;">
		Shamra Exchange Widget 1.0.0
	</p>
        <?php
    }

    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['token'] = ( ! empty( $new_instance['token'] ) ) ? strip_tags( $new_instance['token'] ) : '';
        $instance['source'] = ( ! empty( $new_instance['source'] ) ) ? strip_tags( $new_instance['source'] ) : '';
        $instance['currencies'] = ( ! empty( $new_instance['currencies'] ) ) ? strip_tags( $new_instance['currencies'] ) : '';
        return $instance;
    }
}
